@@ -60,7 +60,7 @@ message_on_prompt <- function(...){
 #'
 #' @description
 #' Shortcut avoiding user to get messages, warnings and being stopped by an
-#' error. The usage is very similar to [base::suppressWarnings()]. This function
+#' error. The usage is very similar to [suppressWarnings()]. This function
 #' is targeted for function creators where user experience enhancement is
 #' sought.
 #'
@@ -71,7 +71,7 @@ message_on_prompt <- function(...){
 #' error, nothing will be returned in that case.
 #'
 #' @seealso
-#' [base::invisible()], [base::suppressWarnings()], [base::suppressMessages()]
+#' [invisible()], [suppressWarnings()], [suppressMessages()]
 #'
 #' @examples
 #' {
@@ -92,11 +92,11 @@ silently_run <- function(...){
 #' Shortcut to turn String character into R code
 #'
 #' @description
-#' Shortcut to [base::parse()] and [base::eval()] evaluate R expression in a
+#' Shortcut to [parse()] and [eval()] evaluate R expression in a
 #' character string, and turns it into actual R code. This function is targeted
 #' for interaction with external files (where expression is stored in text
 #' format) ; for tidy elements where code expression is generated using
-#' [dplyr::mutate()], combined with [base::paste0()] ; in for while, map, etc.
+#' [dplyr::mutate()], combined with [paste0()] ; in for while, map, etc.
 #' loops where character string expression can be indexed or iteratively
 #' generated and evaluated ; objects to be created (using assign, <- or <<- obj)
 #' where the name of the R object is stored in a string. Some issues may occur
@@ -109,7 +109,7 @@ silently_run <- function(...){
 #' Any output generated by the evaluation of the string character.
 #'
 #' @seealso
-#' [base::parse()], [base::eval()]
+#' [parse()], [eval()]
 #'
 #'
 #' @examples
@@ -123,8 +123,6 @@ silently_run <- function(...){
 #'
 #' a <- 1
 #' parceval("print(a)")
-#' my_code <- paste0("a <- a + ",rep(1,3), "; message('value of a: ', a)")
-#' parceval(my_code)
 #'
 #' ##### Example 2 -------------------------------------------------------------
 #' # use rowwise to directly use parceval in a tibble, or use a for loop.
@@ -154,13 +152,13 @@ silently_run <- function(...){
 #'
 #' }
 #'
-#' @import dplyr
+#' @import dplyr stringr
 #' @importFrom rlang .data
 #' @export
 parceval <- function(...){
   eval(
     parse(
-      text = stringr::str_squish(...) %>% stringr::str_remove_all("\\\r")))
+      text = str_squish(...) %>% str_remove_all("\\\r")))
 }
 
 #' @title
@@ -173,6 +171,8 @@ parceval <- function(...){
 #'
 #' @param filename A character string of the path of the Excel file.
 #' @param sheets A vector containing only the sheets to be read.
+#' @param keep_as_list A Boolean to say whether the object should be a list or
+#' a tibble, when there is only one sheet provided. FALSE by default.
 #'
 #' @return
 #' A list of tibbles corresponding to the sheets read, or a single tibble
@@ -188,40 +188,41 @@ parceval <- function(...){
 #'
 #' }
 #'
-#' @import dplyr
+#' @import dplyr readxl purrr
 #' @importFrom rlang .data
 #' @export
-read_excel_allsheets <- function(filename, sheets = "") {
+read_excel_allsheets <- function(filename, sheets = "", keep_as_list = FALSE) {
 
   if(toString(sheets) == ""){
-    sheets_name <- readxl::excel_sheets(filename)
+    sheets_name <- excel_sheets(filename)
   }else{
     sheets_name <-
-      readxl::excel_sheets(filename) %>%
-      as_tibble %>% filter(.data$value %in% c(sheets)) %>%
+      excel_sheets(filename) %>%
+      as_tibble %>% dplyr::filter(.data$value %in% c(sheets)) %>%
       pull(.data$value)
 
     if(length(sheets_name) != length(sheets)){
-      message("{",sheets[!(sheets %in% sheets_name)] %>% toString, "}
-              sheet name(s) not found in the excel file")}}
+      stop(call. = FALSE,
+      "{",sheets[(sheets %in% sheets_name)] %>% toString, "}
+Sheet name(s) not found in the excel file")}}
 
-  if(purrr::is_empty(sheets_name)){
-    message("The sheet name(s) you provided do not exist")}else{
+  if(is_empty(sheets_name)){
+    stop(call. = FALSE, "The sheet name(s) you provided do not exist")}else{
       x <- lapply(sheets_name,
-                  function(X) readxl::read_excel(
+                  function(X) read_excel(
                     path      = filename,
                     sheet     = X,
                     guess_max =
                       suppressWarnings(
-                        readxl::read_excel(filename, sheet = X) %>% nrow)))
+                        read_excel(filename, sheet = X) %>% nrow)))
       names(x) <- sheets_name
-      if(length(x) == 1){return(x[[1]])}else{return(x)}
+      if(length(x) == 1 & keep_as_list == FALSE){return(x[[1]])}else{return(x)}
     }
 }
 
 
 #' @title
-#' Write all Excel sheets using [xlsx::write.xlsx()] recursively
+#' Write all Excel sheets using [writexl::write_xlsx()] recursively
 #'
 #' @description
 #' The R objects are read and the values are placed in separated sheets.
@@ -232,7 +233,7 @@ read_excel_allsheets <- function(filename, sheets = "") {
 #' @param filename A character string of the path of the Excel file.
 #'
 #' @seealso
-#' [xlsx::write.xlsx()]
+#' [writexl::write_xlsx()]
 #'
 #' @return
 #' Nothing to be returned. The file is created at the path declared in the
@@ -248,7 +249,7 @@ read_excel_allsheets <- function(filename, sheets = "") {
 #'
 #' }
 #'
-#' @import dplyr
+#' @import dplyr stringr fs writexl
 #' @importFrom rlang .data
 #' @export
 write_excel_allsheets <- function(list, filename){
@@ -259,13 +260,13 @@ write_excel_allsheets <- function(list, filename){
   if(is.null(objnames)) {
     objnames <-
       as.character(fargs[['expand.dots']]) %>%
-      stringr::str_remove("^list\\(") %>%
-      stringr::str_remove("\\)$") %>%
-      stringr::str_split(", ") %>% unlist
+      str_remove("^list\\(") %>%
+      str_remove("\\)$") %>%
+      str_split(", ") %>% unlist
     names(list) <- objnames}
 
-  fs::dir_create(dirname(filename))
-  writexl::write_xlsx(x = list, path = filename)
+  dir_create(dirname(filename))
+  write_xlsx(x = list, path = filename)
 
 }
 
@@ -284,18 +285,22 @@ write_excel_allsheets <- function(list, filename){
 #' @return
 #' A tibble corresponding to the csv read.
 #'
+#' @seealso [readr::read_csv()], [readr::read_delim()]
+#'
 #' @examples
 #' {
 #'
 #' try(read_csv_any_formats(filename = tempfile()),silent = TRUE)
 #'
 #' }
+#'
+#' @import readr
 #' @importFrom rlang .data
 #' @export
 read_csv_any_formats <- function(filename){
 
-  guess_max <-nrow(silently_run(readr::read_csv(filename, progress = FALSE)))
-  csv <- readr::read_delim(file = filename, guess_max = guess_max)
+  guess_max <-nrow(silently_run(read_csv(filename, progress = FALSE)))
+  csv <- read_delim(file = filename, guess_max = guess_max)
 
   return(csv)
 }
@@ -332,11 +337,11 @@ read_csv_any_formats <- function(filename){
 #' library(dplyr)
 #'
 #' my_tbl <- tibble(iris) %>% group_by(Species) %>% slice(1:3)
-#' fabR::add_index(my_tbl, "my_index")
+#' add_index(my_tbl, "my_index")
 #'
 #' }
 #'
-#' @import dplyr
+#' @import dplyr stringr
 #' @importFrom rlang .data
 #'
 #' @export
@@ -366,7 +371,7 @@ add_index <- function(tbl, name_index = "index", start = 1, .force = FALSE){
   tbl <- tbl %>% mutate(across(all_of(name_index),
                                ~ as.integer(row_number() + start - 1)))
 
-  if(stringr::str_detect(class_tbl,"tbl")) tbl <- tibble(tbl)
+  if(str_detect(class_tbl,"tbl")) tbl <- tibble(tbl)
 
   return(tbl)
 }
@@ -377,14 +382,14 @@ add_index <- function(tbl, name_index = "index", start = 1, .force = FALSE){
 #' @description
 #' Function that recursively go through a list object and store in a tibble the
 #' path of each element in the list. The paths can be after that edited and
-#' accessed using [fabR::parceval()] for example.
+#' accessed using [parceval()] for example.
 #'
 #' @param list_obj R list object to be evaluated
 #' @param .map_list non usable parameter. This parameter is only there to ensure
 #' recursivity. Any modification of this object returns NULL
 #'
 #' @seealso
-#' [fabR::parceval()]
+#' [parceval()]
 #'
 #' @return
 #' A tibble containing all the paths of each element of the list and the
@@ -402,7 +407,7 @@ add_index <- function(tbl, name_index = "index", start = 1, .force = FALSE){
 #'
 #' }
 #'
-#' @import dplyr
+#' @import dplyr stringr tidyr
 #' @importFrom rlang .data
 #' @export
 get_path_list <- function(list_obj, .map_list = NULL){
@@ -425,7 +430,7 @@ get_path_list <- function(list_obj, .map_list = NULL){
 
   }else{
 
-    while(stringr::str_detect(
+    while(str_detect(
       .map_list$map_list$leaf_class %>% toString, "list")){
 
       .map_list$map_list <-
@@ -434,7 +439,7 @@ get_path_list <- function(list_obj, .map_list = NULL){
         mutate(
           leaf_name = names(eval(parse(text = .data$root_name))) %>%
             toString()) %>%
-        tidyr::separate_rows(.data$leaf_name, sep = ", ") %>%
+        separate_rows(.data$leaf_name, sep = ", ") %>%
         rowwise() %>%
         mutate(
           leaf_class2  =
@@ -487,6 +492,7 @@ get_path_list <- function(list_obj, .map_list = NULL){
 #' {
 #'
 #' library(tidyr)
+#' library(stats)
 #'
 #' #### Example 1 --------------------------------------------------------------
 #' # make_name_list generates names that are informative through a line of code
@@ -508,7 +514,7 @@ get_path_list <- function(list_obj, .map_list = NULL){
 #'   .fargs <- as.list(match.call(expand.dots = TRUE))
 #'   list_df <-
 #'     list(df) %>%
-#'     stats::setNames(.,make_name_list(as.character(.fargs['df']),list(df)))
+#'     setNames(.,make_name_list(as.character(.fargs['df']),list(df)))
 #'   return(list_df)}
 #'
 #' my_function(tibble(iris))
@@ -516,27 +522,27 @@ get_path_list <- function(list_obj, .map_list = NULL){
 #'
 #' }
 #'
-#' @import dplyr
+#' @import dplyr stringr
 #' @importFrom rlang .data
 #' @export
 make_name_list <- function(args_list, list_elem){
 
   name_list <-
     args_list %>%
-    stringr::str_squish() %>%
-    stringr::str_split(",") %>%
+    str_squish() %>%
+    str_split(",") %>%
     unlist %>%
-    stringr::str_remove_all("\\(\\)") %>%
-    stringr::str_remove("\\=.*") %>%
-    stringr::str_remove("\\%\\>\\%.*") %>%
-    stringr::str_remove(".*\\([\\`]+") %>%
-    stringr::str_remove("[\\`]+\\).*") %>%
-    stringr::str_remove("\\[.*") %>%
-    stringr::str_remove_all("\\`") %>%
-    stringr::str_remove(".*\\(") %>%
-    stringr::str_remove("\\).*") %>%
-    stringr::str_remove("\\$.*") %>%
-    stringr::str_squish()
+    str_remove_all("\\(\\)") %>%
+    str_remove("\\=.*") %>%
+    str_remove("\\%\\>\\%.*") %>%
+    str_remove(".*\\([\\`]+") %>%
+    str_remove("[\\`]+\\).*") %>%
+    str_remove("\\[.*") %>%
+    str_remove_all("\\`") %>%
+    str_remove(".*\\(") %>%
+    str_remove("\\).*") %>%
+    str_remove("\\$.*") %>%
+    str_squish()
 
   if(length(list_elem) != length(name_list)) {
     warning(
@@ -554,7 +560,7 @@ Please verify the names of your elements and reparse.\n", call. = FALSE)
 #' @description
 #' Create or test for objects of type "logical", and the basic logical
 #' constants.
-#' This function is a wrapper of the function [base::as.logical()] and evaluates
+#' This function is a wrapper of the function [as.logical()] and evaluates
 #' if the object to be coerced can be interpreted as a boolean. Any object :
 #' NA, NA_integer, NA_Date_, (...),
 #' 0, 0L, F, FALSE, false, FaLsE, (...),
@@ -568,7 +574,7 @@ Please verify the names of your elements and reparse.\n", call. = FALSE)
 #' An logical object of the same size.
 #'
 #' @seealso
-#' [base::as.logical()]
+#' [as.logical()]
 #'
 #' @examples
 #' {
@@ -708,7 +714,7 @@ collect_roxygen <- function(folder_r = "R"){
     # trim
     doc %>%
     mutate(value = str_squish(.data$`value`)) %>%
-    filter(str_detect(.data$`value`,"^#'") |
+    dplyr::filter(str_detect(.data$`value`,"^#'") |
              str_detect(.data$`value`, '<- function\\(')) %>%
 
     # classify
@@ -738,10 +744,10 @@ collect_roxygen <- function(folder_r = "R"){
     mutate(value =
              ifelse(
                .data$`class` %in% "FUNCTION",
-               stringr::str_remove(.data$`value`,"<- function.+$"),
+               str_remove(.data$`value`,"<- function.+$"),
                .data$`value`)) %>%
-    mutate(across(everything(), ~stringr::str_squish(.))) %>%
-    filter(.data$`value` != "#'")
+    mutate(across(everything(), ~str_squish(.))) %>%
+    dplyr::filter(.data$`value` != "#'")
 
   doc <-
     doc %>%
