@@ -14,44 +14,46 @@
 #' {
 #'
 #' library(dplyr)
-#' mtcars_duplicated <-
-#'  mtcars %>%
-#'  mutate(
-#'   cyl_2 = cyl,
-#'   cyl_3 = cyl,
-#'   mpg_2 = mpg)
+#' tbl <-
+#'   mtcars %>%
+#'   mutate(
+#'    cyl_2 = cyl,
+#'    cyl_3 = cyl,
+#'    mpg_2 = mpg)
 #'
-#'  get_duplicated_cols(mtcars_duplicated)
+#'  get_duplicated_cols(tbl)
 #'
 #' }
 #'
-#' @import dplyr tidyr
+#' @import dplyr tidyr stringr
+#' @importFrom janitor remove_empty
+#' @importFrom digest digest
 #' @importFrom rlang .data
 #' @export
 get_duplicated_cols <- function(tbl){
 
-  test <- tibble(condition = as.character(), name_var = as.character())
+  test <- tibble(condition = as.character(), col_name = as.character())
   if(tbl %>% nrow() == 0) return(test)
 
   sample_num <- ifelse(nrow(tbl) > 500,500,nrow(test))
 
   test1 <-
     bind_rows(
-      tbl %>% janitor::remove_empty("cols") %>%
+      tbl %>% remove_empty("cols") %>%
         mutate(across(everything(), as.character)) %>%
         slice_sample(n = sample_num, replace = TRUE)) %>%
     rowwise() %>%
-    mutate(across(everything(), ~ digest::digest(.,algo = "md5"))) %>%
-    mutate(across(everything(), ~ stringr::str_sub(., 1, 5))) %>%
+    mutate(across(everything(), ~ digest(.,algo = "md5"))) %>%
+    mutate(across(everything(), ~ str_sub(., 1, 5))) %>%
     ungroup() %>%
     summarise_all(~ paste0(.,collapse = "")) %>%
-    tidyr::pivot_longer(
+    pivot_longer(
       everything(),
       names_to = "condition",
       values_to = "col_1") %>%
     group_by(.data$col_1) %>%
     add_count() %>%
-    filter(n > 1)
+    dplyr::filter(n > 1)
 
   if(nrow(test1) > 0){
 
@@ -61,17 +63,17 @@ get_duplicated_cols <- function(tbl){
           select(all_of(test1$condition)) %>%
           mutate(across(everything(), as.character))) %>%
       rowwise() %>%
-      mutate(across(everything(), ~ digest::digest(.,algo = "md5"))) %>%
-      mutate(across(everything(), ~ stringr::str_sub(., 1, 5))) %>%
+      mutate(across(everything(), ~ digest(.,algo = "md5"))) %>%
+      mutate(across(everything(), ~ str_sub(., 1, 5))) %>%
       ungroup() %>%
       summarise_all(~ paste0(.,collapse = "")) %>%
-      tidyr::pivot_longer(
+      pivot_longer(
         everything(),
         names_to = "condition",
         values_to = "col_1") %>%
       group_by(.data$col_1) %>%
       add_count() %>%
-      filter(n > 1)
+      dplyr::filter(n > 1)
 
     test <- test2
 
@@ -83,24 +85,24 @@ get_duplicated_cols <- function(tbl){
     summarise(
       across(
         everything(),
-        ~ paste("[INFO] - Possible duplicated columns:",
+        ~ paste("Possible duplicated columns:",
                 paste0(., collapse = " ; "))),.groups = "drop") %>%
-    ungroup() %>% select(.data$condition) %>%
-    tidyr::separate(
-      col = .data$condition,
-      into = c("to_remove","name_col"),
+    ungroup() %>% select("condition") %>%
+    separate(
+      col = "condition",
+      into = c("to_remove","col_name"),
       sep = "\\:",
       remove = FALSE) %>%
-    tidyr::separate_rows(.data$name_col, sep = ";") %>%
-    select(-.data$to_remove) %>%
-    mutate(across(everything(), ~stringr::str_squish(.))) %>%
+    separate_rows("col_name", sep = ";") %>%
+    select("condition", "col_name") %>%
+    mutate(across(everything(), ~str_squish(.))) %>%
     mutate(across(everything(), ~as.character(.)))
 
   return(test)
 }
 
 #' @title
-#' Extract observations(rows) that have same values in a tibble
+#' Extract observations (rows) that have same values in a tibble
 #'
 #' @description
 #' This helper function extracts the row number (or first column value) in a
@@ -123,7 +125,7 @@ get_duplicated_cols <- function(tbl){
 #' # the row numbers are returned to identify which observations have repeated
 #' # values
 #' library(dplyr)
-#' get_duplicated_rows(bind_rows(mtcars,mtcars[1,]))
+#' get_duplicated_rows(tbl = bind_rows( tbl = mtcars, mtcars[1,]))
 #'
 #' get_duplicated_rows(
 #'   tbl = bind_rows(mtcars,mtcars[1,]) %>%
@@ -133,19 +135,22 @@ get_duplicated_cols <- function(tbl){
 #'
 #' }
 #'
-#' @import dplyr
+#' @import dplyr stringr tidyr
+#' @importFrom janitor remove_empty
+#' @importFrom digest digest
 #' @importFrom rlang .data
 #' @export
 get_duplicated_rows <- function(tbl, id_col = NULL){
 
-  test <- tibble(condition = as.character(), name_var = as.character())
+  test <- tibble(condition = as.character(), row_number = as.character())
   if(tbl %>% nrow() == 0) return(test)
 
-  test <- tbl %>% janitor::remove_empty("cols")
+  test <- tbl %>% remove_empty("cols")
 
   if(is.null(id_col)) {
-    tbl <- tbl %>% ungroup %>% add_index("__Mlstr_index__",.force = TRUE)
-    test <- test %>% add_index("__Mlstr_index__",.force = TRUE)
+    tbl <-   tbl %>% ungroup %>% add_index("fabR::index",.force = TRUE)
+    test <-  tbl
+    id_col <- "__Mlstr_index__"
   }else{
 
     tbl  <- tbl %>% ungroup %>% select(!! id_col, everything())
@@ -158,42 +163,44 @@ get_duplicated_rows <- function(tbl, id_col = NULL){
     test %>%
     select(1, sample(seq_along(2:ncol(test))+1, sample_num, replace = TRUE)) %>%
     rowwise() %>%
-    mutate(across(-1, ~ digest::digest(.,algo = "md5"))) %>%
-    mutate(across(-1, ~ stringr::str_sub(., 1, 5))) %>%
-    tidyr::unite(-1, col = "row_duplicate", sep = "") %>%
+    mutate(across(-1, ~ digest(.,algo = "md5"))) %>%
+    mutate(across(-1, ~ str_sub(., 1, 5))) %>%
+    unite(-1, col = "row_duplicate", sep = "") %>%
     group_by(.data$row_duplicate) %>%
     add_count() %>%
-    filter(n > 1)
+    dplyr::filter(n > 1)
 
   if(nrow(test1) > 0){
     test2 <-
       test %>%
-      filter(if_any(.cols = 1, ~ . %in% c(unique(test1[[1]])))) %>%
+      dplyr::filter(if_any(.cols = 1, ~ . %in% c(unique(test1[[1]])))) %>%
       # select(-1) %>%
       rowwise() %>%
-      mutate(across(-1, ~ digest::digest(.,algo = "md5"))) %>%
-      mutate(across(-1, ~ stringr::str_sub(., 1, 5))) %>%
-      tidyr::unite(-1, col = "row_duplicate", sep = "") %>%
+      mutate(across(-1, ~ digest(.,algo = "md5"))) %>%
+      mutate(across(-1, ~ str_sub(., 1, 5))) %>%
+      unite(-1, col = "row_duplicate", sep = "") %>%
       # select(2, 1) %>%
       group_by(.data$row_duplicate) %>%
       add_count() %>%
-      filter(n > 1)
+      dplyr::filter(n > 1)
 
     test <- test2
 
   }else{ test <- test1 }
 
+  names(test)[1] <- 'index'
   test <-
     test %>%
     group_by(.data$row_duplicate) %>%
-    summarise_all(
-      ~ paste("[INFO] - Duplicated observations :",
-              paste0(., collapse = " ; "))) %>%
-    ungroup() %>% select(condition = 2)
+    summarise(
+      row_number = paste0(.data$`index`, collapse = " ; ")) %>%
+    mutate(condition = "Duplicated observations") %>%
+    ungroup() %>% select("condition", "row_number")
 
   return(test)
 }
 
+
 #' @title
 #' Extract columns that are all 'NA' from a tibble
 #'
@@ -221,30 +228,36 @@ get_duplicated_rows <- function(tbl, id_col = NULL){
 #'
 #' }
 #'
-#' @import dplyr
+#' @import dplyr tidyr
 #' @importFrom rlang .data
 #' @export
 get_all_na_cols <- function(tbl){
 
+
+  test <- tibble(condition = as.character(), col_name = as.character())
+  if(tbl %>% nrow() == 0) return(test)
+
   # identify columns containing all NA's
   test <-
     tbl %>% summarise(across(everything(), ~ n_distinct(., na.rm = TRUE))) %>%
-    tidyr::pivot_longer(
+    pivot_longer(
       cols = everything(),
-      names_to = "name_col", values_to = "condition") %>%
-    filter(.data$condition == 0) %>%
+      names_to = "col_name", values_to = "condition") %>%
+    dplyr::filter(.data$condition == 0) %>%
     mutate(
-      condition = "[INFO] - Empty column")
+      condition = "Empty column") %>%
+    select("condition","col_name")
 
   return(test)
 }
 
+
 #' @title
-#' Extract columns that are all 'NA' from a tibble
+#' Extract observations (rows) that have all NA values in a tibble
 #'
 #' @description
-#' This helper function extracts the names of the columns in a tibble having NA
-#' values for all observations.
+#' This helper function extracts the row number(s) having NA value for all
+#' columns.
 #'
 #' @param tbl R object(dataframe or tibble) of the input tibble
 #' @param id_col A character string specifying the column to ignore in
@@ -254,21 +267,22 @@ get_all_na_cols <- function(tbl){
 #'
 #' @return
 #' A vector string indicating either that the tibble does not have empty
-#' columns or the names of the empty columns.
+#' observation or the row number of the empty observations.
 #'
 #' @examples
 #' {
 #'
 #' ##### Example 1 -------------------------------------------------------------
 #' # All rows have observation
-#' get_all_na_cols(iris)
+#' get_all_na_rows(iris)
 #'
 #' ##### Example 2 -------------------------------------------------------------
 #' # One row doesn't have any observations
 #' library(dplyr)
 #' get_all_na_rows(bind_rows(iris, tibble(Species = c(NA,NA))))
-#' get_all_na_rows(bind_rows(iris, tibble(Species =  c('an_id', 'another_id'))),
-#'                 id_col = 'Species')
+#' get_all_na_rows(
+#'   tbl = bind_rows(iris, tibble(Species =  c('id_151', 'id_152'))),
+#'   id_col = 'Species')
 #'
 #' }
 #'
@@ -277,7 +291,7 @@ get_all_na_cols <- function(tbl){
 #' @export
 get_all_na_rows <- function(tbl, id_col = NULL){
 
-  test <- tibble(condition = as.character(), name_var = as.character())
+  test <- tibble(condition = as.character(), row_number = as.character())
   if(tbl %>% nrow() == 0) return(test)
 
   if(is.null(id_col)) {
@@ -294,22 +308,24 @@ get_all_na_rows <- function(tbl, id_col = NULL){
     tibble %>%
     mutate(is_na = ncol(test) - .data$is_na) %>%
     bind_cols(tbl[1]) %>%
-    filter(.data$is_na == 1) %>%
-    select(value = last_col()) %>%
-    mutate(value = as.character(.data$`value`)) %>%
+    dplyr::filter(.data$is_na == 1) %>%
+    select(row_number = last_col()) %>%
+    mutate(row_number = as.character(.data$`row_number`)) %>%
     mutate(
-      condition = "[INFO] - Empty observation") %>%
+      condition = "Empty observation") %>%
+    select("condition", "row_number") %>%
     distinct
 
   return(test)
 }
 
+
 #' @title
-#' Extract columns that are all 'NA' from a tibble
+#' Extract columns that have unique values in a tibble
 #'
 #' @description
-#' This helper function extracts the names of the columns in a tibble having NA
-#' values for all observations.
+#' This helper function extracts the names of the columns in a tibble having
+#' unique value for all observations.
 #'
 #' @param tbl R object(dataframe or tibble) of the input tibble
 #'
@@ -326,16 +342,20 @@ get_all_na_rows <- function(tbl, id_col = NULL){
 #'
 #' ##### Example 2 -------------------------------------------------------------
 #' # One column doesn't have distinct observations
-#' get_unique_value_cols(iris[1:50,])
+#' get_unique_value_cols(tbl = iris[1:50,])
 #'
 #' }
 #'
-#' @import dplyr
+#' @import dplyr tidyr
 #' @importFrom rlang .data
 #' @export
 get_unique_value_cols <- function(tbl){
 
-  test <- tibble(condition = as.character(), name_var = as.character())
+  test <- tibble(
+    condition = as.character(),
+    col_name = as.character(),
+    value = as.character())
+
   if(tbl %>% nrow() == 0) return(test)
 
   tbl <- tbl %>% mutate(across(everything(),as.character))
@@ -343,19 +363,20 @@ get_unique_value_cols <- function(tbl){
   # identify columns containing one value
   test <-
     tbl %>% summarise(across(everything(), ~ n_distinct(., na.rm = TRUE))) %>%
-    tidyr::pivot_longer(
+    pivot_longer(
       cols = everything(),
-      names_to = "name_col",
+      names_to = "col_name",
       values_to = "condition") %>%
     rowwise() %>%
     mutate(
       value =
         ifelse(.data$condition == 1,
-               toString(max(pull(tbl[.data$name_col]),na.rm = TRUE)),
+               toString(max(pull(tbl[.data$`col_name`]),na.rm = TRUE)),
                NA_character_)) %>%
-    filter(.data$condition == 1) %>%
+    dplyr::filter(.data$condition == 1) %>%
     mutate(
-      condition = "[INFO] - Unique value in the column")
+      condition = "Unique value in the column") %>%
+    select("condition","col_name","value")
 
   return(test)
 }
